==> python-playwright-1.52.0-1-any.pkg.tar.zst: usr/lib/python3.13/site-packages/playwright/driver/package/lib/utils.js <==
"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __reExport = (target, mod, secondTarget) => (__copyProps(target, mod, "default"), secondTarget && __copyProps(secondTarget, mod, "default"));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var utils_exports = {};
__export(utils_exports, {
  colors: () => import_utilsBundle.colors
});
module.exports = __toCommonJS(utils_exports);
__reExport(utils_exports, require("./utils/isomorphic/colors"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/assert"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/headers"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/locatorGenerators"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/manualPromise"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/mimeType"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/multimap"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/rtti"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/semaphore"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/stackTrace"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/stringUtils"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/time"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/timeoutRunner"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/urlMatch"), module.exports);
__reExport(utils_exports, require("./server/utils/ascii"), module.exports);
__reExport(utils_exports, require("./server/utils/comparators"), module.exports);
__reExport(utils_exports, require("./server/utils/crypto"), module.exports);
__reExport(utils_exports, require("./server/utils/debug"), module.exports);
__reExport(utils_exports, require("./server/utils/debugLogger"), module.exports);
__reExport(utils_exports, require("./server/utils/env"), module.exports);
__reExport(utils_exports, require("./server/utils/eventsHelper"), module.exports);
__reExport(utils_exports, require("./server/utils/expectUtils"), module.exports);
__reExport(utils_exports, require("./server/utils/fileUtils"), module.exports);
__reExport(utils_exports, require("./server/utils/hostPlatform"), module.exports);
__reExport(utils_exports, require("./server/utils/httpServer"), module.exports);
__reExport(utils_exports, require("./server/utils/network"), module.exports);
__reExport(utils_exports, require("./server/utils/nodePlatform"), module.exports);
__reExport(utils_exports, require("./server/utils/processLauncher"), module.exports);
__reExport(utils_exports, require("./server/utils/profiler"), module.exports);
__reExport(utils_exports, require("./server/utils/socksProxy"), module.exports);
__reExport(utils_exports, require("./server/utils/spawnAsync"), module.exports);
__reExport(utils_exports, require("./server/utils/task"), module.exports);
__reExport(utils_exports, require("./server/utils/userAgent"), module.exports);
__reExport(utils_exports, require("./server/utils/wsServer"), module.exports);
__reExport(utils_exports, require("./server/utils/zipFile"), module.exports);
__reExport(utils_exports, require("./server/utils/zones"), module.exports);
var import_utilsBundle = require("./utilsBundle");
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  colors,
  ...require("./utils/isomorphic/colors"),
  ...require("./utils/isomorphic/assert"),
  ...require("./utils/isomorphic/headers"),
  ...require("./utils/isomorphic/locatorGenerators"),
  ...require("./utils/isomorphic/manualPromise"),
  ...require("./utils/isomorphic/mimeType"),
  ...require("./utils/isomorphic/multimap"),
  ...require("./utils/isomorphic/rtti"),
  ...require("./utils/isomorphic/semaphore"),
  ...require("./utils/isomorphic/stackTrace"),
  ...require("./utils/isomorphic/stringUtils"),
  ...require("./utils/isomorphic/time"),
  ...require("./utils/isomorphic/timeoutRunner"),
  ...require("./utils/isomorphic/urlMatch"),
  ...require("./server/utils/ascii"),
  ...require("./server/utils/comparators"),
  ...require("./server/utils/crypto"),
  ...require("./server/utils/debug"),
  ...require("./server/utils/debugLogger"),
  ...require("./server/utils/env"),
  ...require("./server/utils/eventsHelper"),
  ...require("./server/utils/expectUtils"),
  ...require("./server/utils/fileUtils"),
  ...require("./server/utils/hostPlatform"),
  ...require("./server/utils/httpServer"),
  ...require("./server/utils/network"),
  ...require("./server/utils/nodePlatform"),
  ...require("./server/utils/processLauncher"),
  ...require("./server/utils/profiler"),
  ...require("./server/utils/socksProxy"),
  ...require("./server/utils/spawnAsync"),
  ...require("./server/utils/task"),
  ...require("./server/utils/userAgent"),
  ...require("./server/utils/wsServer"),
  ...require("./server/utils/zipFile"),
  ...require("./server/utils/zones")
});

==> python-playwright-1.57.0-1-any.pkg.tar.zst: usr/lib/python3.13/site-packages/playwright/driver/package/lib/utils.js <==
"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __reExport = (target, mod, secondTarget) => (__copyProps(target, mod, "default"), secondTarget && __copyProps(secondTarget, mod, "default"));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var utils_exports = {};
__export(utils_exports, {
  colors: () => import_utilsBundle.colors
});
module.exports = __toCommonJS(utils_exports);
__reExport(utils_exports, require("./utils/isomorphic/ariaSnapshot"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/assert"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/colors"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/headers"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/locatorGenerators"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/manualPromise"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/mimeType"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/multimap"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/protocolFormatter"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/protocolMetainfo"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/rtti"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/semaphore"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/stackTrace"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/stringUtils"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/time"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/timeoutRunner"), module.exports);
__reExport(utils_exports, require("./utils/isomorphic/urlMatch"), module.exports);
__reExport(utils_exports, require("./server/utils/ascii"), module.exports);
__reExport(utils_exports, require("./server/utils/comparators"), module.exports);
__reExport(utils_exports, require("./server/utils/crypto"), module.exports);
__reExport(utils_exports, require("./server/utils/debug"), module.exports);
__reExport(utils_exports, require("./server/utils/debugLogger"), module.exports);
__reExport(utils_exports, require("./server/utils/env"), module.exports);
__reExport(utils_exports, require("./server/utils/eventsHelper"), module.exports);
__reExport(utils_exports, require("./server/utils/expectUtils"), module.exports);
__reExport(utils_exports, require("./server/utils/fileUtils"), module.exports);
__reExport(utils_exports, require("./server/utils/hostPlatform"), module.exports);
__reExport(utils_exports, require("./server/utils/httpServer"), module.exports);
__reExport(utils_exports, require("./server/utils/imageUtils"), module.exports);
__reExport(utils_exports, require("./server/utils/network"), module.exports);
__reExport(utils_exports, require("./server/utils/nodePlatform"), module.exports);
__reExport(utils_exports, require("./server/utils/processLauncher"), module.exports);
__reExport(utils_exports, require("./server/utils/profiler"), module.exports);
__reExport(utils_exports, require("./server/utils/socksProxy"), module.exports);
__reExport(utils_exports, require("./server/utils/spawnAsync"), module.exports);
__reExport(utils_exports, require("./server/utils/task"), module.exports);
__reExport(utils_exports, require("./server/utils/userAgent"), module.exports);
__reExport(utils_exports, require("./server/utils/wsServer"), module.exports);
__reExport(utils_exports, require("./server/utils/zipFile"), module.exports);
__reExport(utils_exports, require("./server/utils/zones"), module.exports);
var import_utilsBundle = require("./utilsBundle");
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  colors,
  ...require("./utils/isomorphic/ariaSnapshot"),
  ...require("./utils/isomorphic/assert"),
  ...require("./utils/isomorphic/colors"),
  ...require("./utils/isomorphic/headers"),
  ...require("./utils/isomorphic/locatorGenerators"),
  ...require("./utils/isomorphic/manualPromise"),
  ...require("./utils/isomorphic/mimeType"),
  ...require("./utils/isomorphic/multimap"),
  ...require("./utils/isomorphic/protocolFormatter"),
  ...require("./utils/isomorphic/protocolMetainfo"),
  ...require("./utils/isomorphic/rtti"),
  ...require("./utils/isomorphic/semaphore"),
  ...require("./utils/isomorphic/stackTrace"),
  ...require("./utils/isomorphic/stringUtils"),
  ...require("./utils/isomorphic/time"),
  ...require("./utils/isomorphic/timeoutRunner"),
  ...require("./utils/isomorphic/urlMatch"),
  ...require("./server/utils/ascii"),
  ...require("./server/utils/comparators"),
  ...require("./server/utils/crypto"),
  ...require("./server/utils/debug"),
  ...require("./server/utils/debugLogger"),
  ...require("./server/utils/env"),
  ...require("./server/utils/eventsHelper"),
  ...require("./server/utils/expectUtils"),
  ...require("./server/utils/fileUtils"),
  ...require("./server/utils/hostPlatform"),
  ...require("./server/utils/httpServer"),
  ...require("./server/utils/imageUtils"),
  ...require("./server/utils/network"),
  ...require("./server/utils/nodePlatform"),
  ...require("./server/utils/processLauncher"),
  ...require("./server/utils/profiler"),
  ...require("./server/utils/socksProxy"),
  ...require("./server/utils/spawnAsync"),
  ...require("./server/utils/task"),
  ...require("./server/utils/userAgent"),
  ...require("./server/utils/wsServer"),
  ...require("./server/utils/zipFile"),
  ...require("./server/utils/zones")
});
